This is a simple library that performs
basic python arithmetic operations.

## Installation
```
pip install jecalculator

```

## Usage:
A guide to using the add_numbers function is as follows

```
import jecalculator as je
add_num = je.add_numbers(3, 7) # where 3 and 7 are the number you want to add
print(add_num)

```
The functions in this library are:
1. add_numbers
2. subtract_numbers
3. multiply_numbers 
4. divide_numbers_float 
5. divide_numbers_floor
6. power_numbers
7. mode_numbers

## License
Copyright 2022 jamalelkhdadi

This repository is licensed under MIT license.
See LICENSE for details.
